# eric7.RemoteServerInterface

Package implementing the components of the eric-ide remote server interface.

### Modules

EricServerConnectionDialog | Module implementing a dialog to enter the parameters for a connection to an eric-ide server.
EricServerCoverageInterface | Module implementing the code coverage interface to the eric-ide server.
EricServerDebuggerInterface | Module implementing the file system interface to the eric-ide server.
EricServerEditorConfigInterface | Module implementing the Editor Config interface to the eric-ide server.
EricServerFileDialog | Module implementing a file dialog showing the file system of the eric-ide server.
EricServerFileSystemInterface | Module implementing the file system interface to the eric-ide server.
EricServerInterface | Module implementing the interface to the eric remote server.
EricServerProfilesDialog | Module implementing a dialog to manage server connection profiles.